SystemOrganization addCategory: #'WebStoreTests-Core'!
SystemOrganization addCategory: #'WebStoreTests-UI'!
SystemOrganization addCategory: #'WebStoreTests-Commands'!
SystemOrganization addCategory: #'WebStoreTests-Resources'!
SystemOrganization addCategory: #'WebStoreTests-Site'!
SystemOrganization addCategory: #'WebStoreTests-Util'!
SystemOrganization addCategory: #'WebStoreTests-Admin'!

TestResource subclass: #WSMagmaResource
	instanceVariableNames: 'location session'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Resources'!

!WSMagmaResource methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 17:35'!
session
	session ifNil: [session := location newSession connectAs: 'testing'].
	^session! !

!WSMagmaResource methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:01'!
setUp
	location := MagmaLocalLocation path: 'testing.magma'.
	location isRepository 
		ifFalse: [MagmaRepositoryController create: location path root: Dictionary new]
		ifTrue: [[self session root: (Dictionary new)] on: Warning do: ["nothing"] ].! !

!WSMagmaResource methodsFor: 'as yet unclassified' stamp: 'srh 3/29/2009 20:41'!
tearDown
	session ifNotNil: [ session disconnect; closeRepository].! !

WSImage subclass: #WSDummyImage
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Resources'!

!WSDummyImage class methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:31'!
baseName: aName
	^self new
		baseName: aName;
		yourself.! !

!WSDummyImage methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 11:27'!
baseName: aString
	baseName := aString! !

WSRoot subclass: #TestSite
	instanceVariableNames: 'products cartWidget'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Site'!

!TestSite class methodsFor: 'as yet unclassified' stamp: 'srh 12/28/2008 12:53'!
canBeRoot
	^true! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 14:30'!
children
	^Array with: products with: cartWidget.! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 3/21/2009 11:40'!
initialize
	super initialize.
	products := WSProductList products: self store products.
	cartWidget := WSCartWidget new.
	self addListener: (WSCartListener cart: self session cart).! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 1/1/2009 10:03'!
renderContentOn: html
	html heading id: 'banner'; with: 'Emma''s Store'.
	html div id: 'nav';with: [
		html unorderedList with: [
			html listItem: [ html anchor callback: []; with: 'Home'].
			html listItem: [ html anchor callback: []; with: 'A link'].
		].
		html render: cartWidget.
	].
	html div id: 'content';with:products! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 1/2/2009 17:26'!
store
	^self session store! !

!TestSite methodsFor: 'as yet unclassified' stamp: 'srh 12/31/2008 12:58'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot	stylesheet 
		url: TestSiteFiles  / #webstoreCss! !

TestCase subclass: #WSAddressTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSAddressTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 21:11'!
testPopulateFrom
	| a1 a2 |
	a2 := WSAddress new.
	a1 := WSShippingAddress new.
	
	a2 address1: 'a'.
	a2 address2: 'b'.
	a2 locality: 'c'.
	a2 state: 'd'.
	a2 postcode: 'e'.
	a2 country: 'f'.
	
	a1 populateFrom: a2.
	self assert: a2 address1 = a1 address1.	
	self assert: a2 address2 = a1 address2.
	self assert: a2 locality = a1 locality.	
	self assert: a2 postcode = a1 postcode.
	self assert: a2 state =  a1 state.
	self assert: a2 country = a1 country.
	self deny: a2 == a1.		! !

TestCase subclass: #WSCartTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSCartTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 21:13'!
testAdd
	|c p|
	c := WSCart new.
	p := WSProduct new.
	c add: p.
	
	self assert: (c items includes: p).! !

!WSCartTest methodsFor: 'as yet unclassified' stamp: 'srh 6/28/2009 22:21'!
testNewInstance
	| c |
	c := WSCart new.
	self assert: c isEmpty! !

!WSCartTest methodsFor: 'as yet unclassified' stamp: 'srh 6/28/2009 22:21'!
testNotEmpty
	| c |
	c := WSCart new.
	c add: WSProduct new.
	self deny: c isEmpty! !

!WSCartTest methodsFor: 'as yet unclassified' stamp: 'srh 2/27/2009 21:09'!
testRemove
	|c p|
	c := WSCart new.
	p := WSProduct new.
	c add: p.
	c remove: p.
	
	self deny: (c items includes: p).! !

!WSCartTest methodsFor: 'as yet unclassified' stamp: 'srh 8/4/2009 16:08'!
testTotalInDollars
	|c p1 p2|
	c := WSCart new.
	p1 := WSProduct new.
	p2 := WSProduct new.
	p1  price: 12345.
	p2 price: 54321.
	c add: p1.
	c add: p2.
	
	self assert: ('666.66' = c totalInDollars).! !

TestCase subclass: #WSCommandTestCase
	instanceVariableNames: 'session store'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Commands'!

WSCommandTestCase subclass: #WSApplyFormCommandTest
	instanceVariableNames: 'product form nameField priceField descriptionField'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Commands'!

!WSApplyFormCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 2/27/2009 21:05'!
setUp
	super setUp.
	product := store products first.
	form := WSForm new.
	nameField := WSTestingField new on: #name of: product;
				 beRequired;
				 yourself.
	priceField := WSTestingField new on: #price of: product;
				 beRequired;
				 yourself.
	descriptionField := WSTestingField new on: #description of: product;
				 yourself.
				
	form 
		add: nameField;
		add: priceField;
		add: descriptionField.! !

!WSApplyFormCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 21:12'!
testUpdateDescription
	self updateForm.
	self runCommand: [WSApplyFormCommand form: form].
	session abort.
	self assert: 'testing' = product description! !

!WSApplyFormCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 21:12'!
testUpdateName
	self updateForm.
	self runCommand: [WSApplyFormCommand form: form].
	session abort.
	self assert: 'newName' = product name! !

!WSApplyFormCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 21:12'!
testUpdatePrice
	self updateForm.
	self runCommand: [WSApplyFormCommand form: form].
	session abort.
	self assert: 666 = product price! !

!WSApplyFormCommandTest methodsFor: 'as yet unclassified' stamp: 'srh 2/27/2009 21:06'!
updateForm
	nameField value: 'newName'.
	priceField value: 666.
	descriptionField value: 'testing'! !

!WSCommandTestCase class methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 23:08'!
resources
	^Array with: WSMagmaResource! !

!WSCommandTestCase methodsFor: 'as yet unclassified' stamp: 'srh 4/20/2009 22:04'!
runCommand: aBlock 
	"aBlock should return a new Command"
	WSCurrentTransactionProvider  
		use: [ session ]
		during: [ aBlock value run ]! !

!WSCommandTestCase methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:10'!
setUp
	super setUp.
	session := WSMagmaResource current session.
	store := WSTestingStore store.
	session commit: 
		[ session root 
			at: self class name
			put: store ].
! !

WSCommandTestCase subclass: #WSOrderCommandsTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Commands'!

!WSOrderCommandsTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 21:32'!
testCancelOrder
	|order|
	order := store orders first.
	self runCommand: [WSCancelOrderCommand order: order reason: 'because'].
	session abort.
	self assert: (order status is: #cancelled)
! !

!WSOrderCommandsTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testCancelOrderReason
	| order |
	order := store orders first.
	self runCommand: 
		[ WSCancelOrderCommand 
			order: order
			reason: 'because' ].
	session abort.
	self assert: 'because' = order status reason! !

!WSOrderCommandsTest methodsFor: 'as yet unclassified' stamp: 'srh 6/26/2009 21:12'!
testPlaceOrder
	| order |
	order := WSOrder new.
	order items: WSCart new.
	order items add: store products first.
	order customer: (WSCustomer new email: 'test@example.com';yourself).
		
	self runCommand: [WSPlaceOrderCommand store: store order: order].
	session abort.
	self assert: (order status is: #unconfirmed)
! !

!WSOrderCommandsTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 21:32'!
testShipOrder
	| order |
	order := store orders at: 3.
	self runCommand: [WSShipOrderCommand order: order].
	session abort.
	self assert: (order status is: #shipped)! !

WSCommandTestCase subclass: #WSTestProductCommands
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Commands'!

!WSTestProductCommands methodsFor: 'tests (slow)' stamp: 'srh 1/26/2009 13:39'!
testAddImage
	| p i |
	p := store products first.
	i := WSDummyImage baseName: 'newimage'.
	self runCommand:
		[ WSAddImageCommand 
			product: p
			image: i ].
	session abort.
	self assert: (p images includes: i)! !

!WSTestProductCommands methodsFor: 'tests (slow)' stamp: 'srh 3/28/2009 22:47'!
testAddProduct
	| p |
	p := WSProduct new.
	self runCommand: 
		[ WSAddProductCommand 
			store: store
			product: p ].
	session abort.
	self assert: (store products includes: p)! !

!WSTestProductCommands methodsFor: 'tests (slow)' stamp: 'srh 1/26/2009 00:16'!
testDeleteImage
	| p i |
	p := store products first.
	i := p images first.
	self runCommand: 
		[ WSDeleteImageCommand 
			product: p
			image: i ].
	session abort.
	self deny: (p images includes: i)! !

!WSTestProductCommands methodsFor: 'tests (slow)' stamp: 'srh 2/28/2009 21:36'!
testDeleteProduct
	| p |
	p := store products first.
	self runCommand: [ WSDeleteProductCommand store: store product: p].
	session abort.
	self deny: (store products includes: p).! !

!WSTestProductCommands methodsFor: 'tests (slow)' stamp: 'srh 2/28/2009 21:33'!
testDisable
	| p |
	p := store products first.
	self runCommand: 
		[ WSDisableProductCommand 
			product: p].
	session abort.
	self deny: p enabled.! !

!WSTestProductCommands methodsFor: 'tests (slow)' stamp: 'srh 2/28/2009 21:31'!
testEnable
	| p |
	p := store products third.
	self runCommand: 
		[ WSEnableProductCommand 
			product: p].
	session abort.
	self assert: p enabled.! !

!WSTestProductCommands methodsFor: 'tests (slow)' stamp: 'srh 3/28/2009 22:45'!
testSetPreview
	| p i |
	p := store products first.
	i := p images second.
	self runCommand: 
		[ WSSetPreviewCommand 
			product: p
			image: i ].
	session abort.
	self assert: i = p preview! !

TestCase subclass: #WSCountryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSCountryTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 10:59'!
testByCode
	self assert: (WSCountry byCode: 'AU') notNil! !

!WSCountryTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 10:58'!
testCountryList
	self assert: WSCountry countryList notEmpty.! !

!WSCountryTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 11:03'!
testLookupAustralia
	self assert: ('Australia' = (WSCountry byCode: 'AU') name)! !

!WSCountryTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 11:03'!
testLookupNewZealand
	self assert: ('New Zealand' = (WSCountry byCode: 'NZ') name)! !

TestCase subclass: #WSImageTest
	instanceVariableNames: 'image'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSImageTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 15:04'!
setUp
	image := WSImage new! !

!WSImageTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 17:59'!
testNamePattern
	self assert: (image fullsize matchesRegex: '^[0-9a-f\-]+-full.jpg')! !

TestCase subclass: #WSOrderTest
	instanceVariableNames: 'order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 6/26/2009 21:08'!
setUp
	super setUp.
	order := WSOrder new 
		items: (WSCart new add: WSProduct new;yourself); 
		customer: (WSCustomer new email: 'test@example.com');
		yourself.
! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 14:39'!
testCancelledOrderStatus
	order placeOrder: 123.
	order cancel: 'because'.
	self assert: (order status is: #cancelled)! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 14:38'!
testCantShipCancelledOrder
	order placeOrder: 123.
	order cancel: 'vecause'.
	self should: [order ship] raise: Error description: 'shouldn''t be able to ship a cancelled order'.
! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 21:15'!
testCantShipNewOrder
	self should: [order ship] raise: Error description: 'shouldn''t be able to ship a new order'.
! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 14:43'!
testConfirmPayment
	order placeOrder: 123.
	order confirmPayment: 'abc'.
	self assert: (order status is: #confirmed).! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testInitialOrderHistory
	self assert: 1 = order history size! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testInitialOrderHistoryContents
	self assert: order status = order history last! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 16:13'!
testNewOrderDate
	self should: [order date] raise: Error whoseDescriptionIncludes: 'been placed yet' description: 'new order shouldn''t have date'! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:06'!
testNewReference
	self assert: order reference isNil! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 13:24'!
testNewStatus
	self assert: (order status is: #new)! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 16:06'!
testOrderDate
	| time |
	time := DateAndTime now.
	order placeOrder: 123.
	self assert: (order date between: time and: time + 2 seconds)! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testOrderHistory
	order placeOrder: 123.
	order confirmPayment: 'xyz'.
	order ship.
	self assert: 4 = order history size! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 13:29'!
testOrderHistoryContents
	order placeOrder: 123.
	order confirmPayment: 'xyz'.
	order ship.
	self assert: ((order history at: 3) is:  #confirmed)! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testOrderReference
	order placeOrder: 123.
	self assert: 123 = order reference! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 13:24'!
testOrderStatus
	order placeOrder: 123.
	self assert: (order status is: #unconfirmed).! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testPaymentReference
	order placeOrder: 123.
	order confirmPayment: 'abc'.
	self assert: 'abc' = order status reference! !

!WSOrderTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 14:46'!
testShippedStatus
	order placeOrder: 123.
	order confirmPayment: 'abc'.
	order ship.
	self assert: (order status is: #shipped)! !

TestCase subclass: #WSPersistenceTest
	instanceVariableNames: 'magmaSession'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSPersistenceTest class methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 16:24'!
resources
	^Array with: WSMagmaResource! !

!WSPersistenceTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 17:31'!
setUp
	magmaSession := WSMagmaResource current session.! !

!WSPersistenceTest methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 16:35'!
testAbort
	| s p |
	p := WSProduct new.
	s := WSStore new.
	magmaSession commit: [
		magmaSession root at: self class name put: s].
	
	magmaSession begin.
	s addProduct: p.
	magmaSession abort.
	self deny: (s products includes: p).! !

!WSPersistenceTest methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 16:37'!
testCommit
	| s p |
	p := WSProduct new.
	s := WSStore new.
	magmaSession commit: [
		magmaSession root at: self class name put: s].
	
	magmaSession begin.
	s addProduct: p.
	magmaSession commit.
	self assert: (s products includes: p).! !

!WSPersistenceTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testPersist
	| s |
	s := WSStore new.
	magmaSession commit: 
		[ magmaSession root 
			at: self class name
			put: s ].
	self assert: s = (magmaSession root at: self class name)! !

TestCase subclass: #WSProductTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testAddFirstImageSetsPreview
	| p i |
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	self assert: i = p preview! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:47'!
testAddImage
	| p i |
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	self assert: (p images includes: i)! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 20:53'!
testNewProduct
	|p|
	p := WSProduct new.
	self assert: p images isEmpty.! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testOrderCopy
	| p1 p2 |
	p1 := WSProduct new.
	p1 name: 'p1'.
	p2 := p1 orderCopy.
	self assert: 'p1' = p2 name! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testOrderCopyDifferent
	| p1 p2 |
	p1 := WSProduct new.
	p1 name: 'p1'.
	p2 := p1 orderCopy.
	p1 name: 'xx'.
	self assert: 'p1' = p2 name! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 3/21/2009 14:17'!
testOrderCopyOptions
	| p1 p2 |
	p1 := WSProduct new.
	p1 options: (Array with: WSTextOption new).
	p2 := p1 orderCopy.
	p2 options first text: 'blah'.
	self assert: p1 options first text isNil.! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:25'!
testPreviewMustBeInImages
	| p i1 i2 |
	p := WSProduct new.
	i1 := WSImage new.
	i2 := WSImage new.
	
	p addImage: i1.
	self should: [p preview: i2] raise: Exception whoseDescriptionIncludes: 'must be one of the product''s images'  description: 'Didn''t raise expected Exception'! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 8/4/2009 15:41'!
testPriceInDollars
	self assert: ('30.40' = (WSProduct new
				price: 3040;
				priceInDollars))! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 09:57'!
testProductIdImmutableOnceSet
	| p |
	p := WSProduct new.
	p id: 1.
	self should: [p id: 2] raise: Error! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:05'!
testRemoveImage
	|p i|
	
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	p removeImage: i.
	
	self assert: (p images includes: i) not.! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testRemoveImageResetsPreview
	| p i1 i2 |
	p := WSProduct new.
	i1 := WSImage new.
	i2 := WSImage new.
	p addImage: i1.
	p addImage: i2.
	p preview: i2.
	p removeImage: i2.
	self assert: i1 = p preview! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 12/30/2008 21:07'!
testRemoveLastImageUnsetsPreview
	|p i|
	
	p := WSProduct new.
	i := WSImage new.
	p addImage: i.
	p removeImage: i.
	
	self assert: p preview isNil..! !

!WSProductTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testSetPreview
	| p i1 i2 |
	p := WSProduct new.
	i1 := WSImage new.
	i2 := WSImage new.
	p addImage: i1.
	p addImage: i2.
	p preview: i2.
	self assert: i2 = p preview! !

TestCase subclass: #WSStatusTest
	instanceVariableNames: 'status'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 11:50'!
setUp
	status := WSStatus newFor: self! !

!WSStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 13:40'!
status: aState 
	status := aState! !

!WSStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testChangeState
	status placeOrder.
	self assert: status class = WSUnconfirmedStatus! !

!WSStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 11:53'!
testDate
	| time |
	time := DateAndTime now.
	self assert: (status date 
			between: time - 1 seconds
			and: time + 1 seconds)! !

!WSStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 11:52'!
testIs
	self assert: (status is: #new)! !

!WSStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 11:52'!
testIsNot
	self deny: (status is: #foo)! !

!WSStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testName
	self assert: #new = status name! !

!WSStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testNew
	self assert: WSNewStatus = status class! !

TestCase subclass: #WSStatusesTest
	instanceVariableNames: 'actionMap status'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

WSStatusesTest subclass: #WSCancelledStatusTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSCancelledStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 14:04'!
setUp
	super setUp.
	status := WSCancelledStatus owner: self reason: 'because'.! !

!WSCancelledStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 21:12'!
testReason
	self assert: 'because' = status reason.! !

WSStatusesTest subclass: #WSConfirmedStatusTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSConfirmedStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 13:56'!
setUp
	super setUp.
	status := WSConfirmedStatus owner: self reference: '1234'.
	actionMap at: #ship put: #shipped.
	actionMap at: #cancel: put: #cancelled! !

!WSConfirmedStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testCancelReason
	status cancel: 'because'.
	self assert: 'because' = status reason! !

!WSConfirmedStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testReference
	self assert: '1234' = status reference! !

WSStatusesTest subclass: #WSNewStatusTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSNewStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 12:19'!
setUp
	super setUp.
	status := WSNewStatus owner: self.
	actionMap at: #placeOrder put: #unconfirmed! !

WSStatusesTest subclass: #WSShippedStatusTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSShippedStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 14:02'!
setUp
	super setUp.
	status := WSShippedStatus owner: self.! !

!WSStatusesTest class methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 12:14'!
isAbstract
	^self = WSStatusesTest! !

!WSStatusesTest class methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 12:10'!
shouldInheritSelectors
	^true! !

!WSStatusesTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 12:30'!
assert: aBlock resultsIn: aStatusName 
	aBlock value.
	self assert: (status is: aStatusName)! !

!WSStatusesTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 12:29'!
assertAction: aSymbol
	self assertAction: aSymbol withArguments: #().! !

!WSStatusesTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 12:28'!
assertAction: aSymbol withArguments: args
	| block |
	block := [ status perform: aSymbol withArguments: args].
	(actionMap includesKey: aSymbol) 
		ifTrue: [self assert: block resultsIn: (actionMap at: aSymbol)]
		ifFalse: [self assertInvalidStateChange: block]
! !

!WSStatusesTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 12:30'!
assertInvalidStateChange: aBlock 
	self 
		should: [ aBlock value ]
		raise: Error
		whoseDescriptionIncludes: 'does not make sense'
		description: 'Action should have failed'! !

!WSStatusesTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 12:01'!
setUp
	actionMap := Dictionary new.! !

!WSStatusesTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 13:40'!
status: aStatus 
	status := aStatus! !

!WSStatusesTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 14:08'!
testCancel
	self assertAction: #cancel: withArguments: #('because')! !

!WSStatusesTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 12:37'!
testConfirmPayment
	self assertAction: #confirmPayment: withArguments: (Array with: '1234')! !

!WSStatusesTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 12:15'!
testPlaceOrder
	self assertAction: #placeOrder! !

!WSStatusesTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 12:02'!
testShip
	self assertAction: #ship! !

WSStatusesTest subclass: #WSUnconfirmedStatusTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSUnconfirmedStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 13:56'!
setUp
	super setUp.
	status := WSUnconfirmedStatus  owner: self.
	actionMap at: #confirmPayment: put: #confirmed.
	actionMap at: #cancel: put: #cancelled.! !

!WSUnconfirmedStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testCancelReason
	status cancel: 'because'.
	self assert: 'because' = status reason! !

!WSUnconfirmedStatusTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testConfirmedReference
	status confirmPayment: '1234'.
	self assert: '1234' = status reference! !

TestCase subclass: #WSStoreTest
	instanceVariableNames: 'store p order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Core'!

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 6/26/2009 21:10'!
setUp
	super setUp.
	store := WSStore new.
	p := WSProduct new.
	order := WSOrder new 
		items: (WSCart new add: p;yourself); 
		customer: (WSCustomer new email: 'test@example.com';yourself);
		yourself.! !

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:16'!
testAddProduct
	store addProduct: p.
	self assert: (store products includes: p).
	! !

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:16'!
testDeleteProduct
	store addProduct: p.
	store deleteProduct: p.
	self assert: (store products includes: p) not	! !

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 21:06'!
testOrderReference
	store placeOrder: order.
	self assert: order reference notNil.! !

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:47'!
testPlaceOrder
	store placeOrder: order.
	self assert: (store orders includes: order)! !

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 4/11/2009 12:32'!
testProductById
	store addProduct: WSProduct new.
	store addProduct: p.
	store addProduct: WSProduct new.
	self assert: p = (store productWithId: p id)! !

!WSStoreTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 09:54'!
testProductId
	store addProduct: p.
	self assert: p id notNil.	! !

WAFileLibrary subclass: #TestSiteFiles
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Site'!

!TestSiteFiles methodsFor: 'uploaded' stamp: 'srh 1/1/2009 22:15'!
webstoreCss
	^ '
#banner {
	position: absolute;
	top: 0;
	height: 2em;
	left: 0;
	right: 0;
	margin:0;
	font-size: 2em;
	border-bottom: solid 1px grey;
}
#nav {
	position: absolute;
	left: 0;
	top: 4em;
	width: 8em;
}

#content {
	position: absolute;
	top: 4em;
	left: 8em;
	margin-top: 0;
	border-left: solid 1px grey;
	padding-left: 1em;
	padding-top: 5px;
}

.product-preview {
	float: left;
	border: dashed 1px grey;
	margin: 3px;
	height: 8.5em;
	width: 12em;
	padding: 3px;
}

.product-preview img {
	float: left;
	margin-right: 0.5em;
	margin-bottom: 0.5em;
}
.product-preview h3 {
	margin-top: 0;
	margin-bottom: 0;
	font-size: 1em;
	clear: both;
}
.product-preview p {
	margin-top: 0;
	margin-bottom: 0;
}

.product-preview a {
	text-decoration: none;
}

.product-preview img {
	border: none;
}

.product-details {
	margin-bottom: 2em;
}

.product-details h2 {
	margin-top: 0;
}

.product-details .image-viewer {
	float: left;
	margin-right: 1em;
	margin-bottom: 0.5em;
}

.image-viewer {
	border: solid grey 1px;
	padding: 0;
	text-align: center;
}

.image-viewer img {
	border:none;
	padding: none;
}

.image-viewer ul {
	margin: 0;
	padding: 0;
	list-style: none;
	border-top: solid grey 1px;
	background-color: #eeeeee;
}

.image-viewer li {
	display: inline;
	margin: 0;
	padding: 0;
}

#lightbox {
	background-color: white;
	border: solid #404040 1px;
}

#lightbox h1 {
	background-color: #eeeeee;
	margin-top: 0;
	padding: 2x;
	text-align: center;
	font-size: 1.2em;
}

#lightbox .nav-buttons {
	background-color: #eeeeee;
	padding: 0.2em;
	text-align: right;
}

ul.wizard-tabs {
	list-style: none;
	margin: 0;
	padding: 0;
}

.wizard-tabs li {
	display: inline;
	margin-left: 0.5em;
	margin-right: 0.5em;
}

.wizard-tabs li.disabled {
	color: grey;
}

.cart-view {
	margin: 0.5em;
}

#confirm-order {
	padding-left: 0.5em;
	padding-right: 0.5em;
}

#confirm-order h2 {
	margin-top: 0;
	margin-bottom: 0;
	font-size: 1.2em;
}

#confirm-order div {
	margin: 0;
}
#confirm-order p {
	margin-top: 0;
}

#confirm-order dl {
	margin-top: 0.5em;
	padding: 0;
}

#confirm-order dt {
	font-weight: bold;
}

#confirm-order dd {
	margin-left: 8em;
	margin-top: -1em;
}

label {
	width: 10em;
	display: inline-block;
	text-align: right;
	margin-right: 0.5em;
}
'! !

WSSession subclass: #TestSiteSession
	instanceVariableNames: 'cart'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Site'!

!TestSiteSession methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 21:48'!
cart
	^cart! !

!TestSiteSession methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 21:47'!
initialize
	super initialize.
	self resetCart! !

!TestSiteSession methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 21:48'!
resetCart
	cart := WSCart new! !

WSSession subclass: #WSTestSession
	instanceVariableNames: 'cart'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 21:49'!
cart
	^cart! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 18:13'!
cart: aCart
	cart := aCart! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 10:16'!
commit: aBlock
	aBlock value! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 10:18'!
initialize
	super initialize.
	self setUpStore.
	self resetCart! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:36'!
magmaSession
	^magmaSession ifNil: [magmaSession := WSTransactionalStub new]! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:56'!
magmaSession: aSession
	magmaSession := aSession! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 10:18'!
resetCart
	cart := WSCart new.! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 2/27/2009 20:51'!
setUpStore
	store := WSStore new.
	store addProduct: (WSProduct new
		name: 'Test product 1';
		description:  'Product description 1';
		price: 12345;
		enable;
		yourself).
	store addProduct: (WSProduct new
		name: 'Test product 2';
		description:  'Product description 2';
		price: 33000;
		enable;
		yourself).
	store addProduct: (WSProduct new
		name: 'Test product 3';
		description:  'Product description 3';
		price: 44000;
		disable;
		yourself).! !

!WSTestSession methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 12:06'!
store: aStore
	store := aStore! !

Object subclass: #WSTestingStore
	instanceVariableNames: 'store'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Resources'!

!WSTestingStore class methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:36'!
new
	^self basicNew
		initialize;
		yourself.! !

!WSTestingStore class methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:37'!
store
	^self new store! !

!WSTestingStore methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 11:52'!
addOrders
	store placeOrder: (WSOrder new
		customer: (WSCustomer new
			name: 'Customer1';
			email: 'cust1@example.com';
			yourself);
		address: (WSShippingAddress new
			name: 'o1 recipient';
			address1: 'o1 Ship address 1';
			address2: 'o1 Ship address 2';
			locality: 'o1 Suburb';
			state: 'o1 State';
			postcode: 'o1 1234';
			country: (WSCountry byCode: 'AU');
			yourself);
		items: (WSCart new
			add: store products first;
			add: (store products at: 4);
			yourself)).

	store placeOrder: (WSOrder new
		customer: (WSCustomer new
			name: 'Customer2';
			email: 'cust2@example.com';
			yourself);
		address: (WSShippingAddress new
			name: 'recipient';
			address1: 'Ship address 1';
			address2: 'Ship address 2';
			locality: 'Suburb';
			state: 'State';
			postcode: '1234';
			country: (WSCountry byCode: 'US');
			yourself);
		items: (WSCart new
			add: store products first;
			add: store products first;
			yourself)).
	store orders second cancel: 'because'.
	store placeOrder: (WSOrder new
		customer: (WSCustomer new
			name: 'Customer1';
			email: 'cust1@example.com';
			yourself);
		address: (WSShippingAddress new
			name: 'recipient';
			address1: 'Ship address 1';
			address2: 'Ship address 2';
			locality: 'Suburb';
			state: 'State';
			postcode: '1234';
			country: (WSCountry byCode: 'NZ');
			yourself);
		items: (WSCart new
			add: store products first;
			add: store products first;
			yourself)).
		store orders last confirmPayment: '1234'.
	store placeOrder: (WSOrder new
		customer: (WSCustomer new
			name: 'Customer4';
			email: 'cust4@example.com';
			yourself);
		address: (WSShippingAddress new
			name: 'o4 recipient';
			address1: 'o4 Ship address 1';
			address2: 'o4 Ship address 2';
			locality: 'Suburb';
			state: 'State';
			postcode: '1234';
			country: 'DE';
			yourself);
		items: (WSCart new
			add: store products first;
			add: store products second;
			yourself)).
		store orders last confirmPayment: '1234'; ship.! !

!WSTestingStore methodsFor: 'as yet unclassified' stamp: 'srh 2/27/2009 20:52'!
addProducts
	store addProduct: (WSProduct new
		name: 'Test product 1';
		description:  'Product description 1';
		price: 12345;
		enable;
		addImage: (WSDummyImage baseName: 'p1-i1');
		addImage: (WSDummyImage baseName: 'p1-i2');
		addImage: (WSDummyImage baseName: 'p1-i3');		
		yourself).

	store addProduct: (WSProduct new
		name: 'Test product 2';
		description:  'Product description 2';
		price: 33000;
		enable;
		addImage: (WSDummyImage baseName: 'p2-i1');
		yourself).
	store addProduct: (WSProduct new
		name: 'Test product 3';
		description:  'Product description 3';
		price: 44000;
		addImage: (WSDummyImage baseName: 'p3-i1');
		disable;
		yourself).
		
	store addProduct: (WSProduct new
		name: 'Test product 4';
		description:  'Product description 4';
		price: 12345;
		enable;
		addImage: (WSDummyImage baseName: 'p4-i1');
		addImage: (WSDummyImage baseName: 'p4-i2');
		addImage: (WSDummyImage baseName: 'p4-i3');		
		yourself).! !

!WSTestingStore methodsFor: 'as yet unclassified' stamp: 'srh 3/21/2009 21:27'!
initialize
	store := WSStore new.
	self addProducts.
	self addOrders.
! !

!WSTestingStore methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:33'!
store
	^store! !

Object subclass: #WSTransactionalStub
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Resources'!

!WSTransactionalStub methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:35'!
abort! !

!WSTransactionalStub methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 00:35'!
commit: aBlock
	aBlock value! !

!WSTransactionalStub methodsFor: 'as yet unclassified' stamp: 'srh 4/20/2009 22:07'!
refresh! !

WAComponent subclass: #WSComponentHolder
	instanceVariableNames: 'children'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

!WSComponentHolder methodsFor: 'as yet unclassified' stamp: 'srh 3/9/2009 16:06'!
add: aComponent
	children add: aComponent! !

!WSComponentHolder methodsFor: 'as yet unclassified' stamp: 'srh 3/10/2009 21:43'!
announce: anAnnouncement
	^self session announce: anAnnouncement! !

!WSComponentHolder methodsFor: 'as yet unclassified' stamp: 'srh 3/9/2009 16:35'!
children
	^children select: [ :c | c isKindOf: WAComponent ]! !

!WSComponentHolder methodsFor: 'as yet unclassified' stamp: 'srh 3/10/2009 21:35'!
initialize
	super initialize.
	children := OrderedCollection new.
	self session on: WSLightbox do: [:ann| self lightbox: ann component ]! !

!WSComponentHolder methodsFor: 'as yet unclassified' stamp: 'srh 3/9/2009 16:07'!
renderContentOn: html
	children do: [ :c | html render: c ]! !

WAComponent subclass: #WSFieldHolder
	instanceVariableNames: 'fields'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Util'!

!WSFieldHolder methodsFor: 'as yet unclassified' stamp: 'srh 3/8/2009 10:41'!
add: aField
	fields add: aField! !

!WSFieldHolder methodsFor: 'as yet unclassified' stamp: 'srh 3/8/2009 10:40'!
children
	^fields! !

!WSFieldHolder methodsFor: 'as yet unclassified' stamp: 'srh 3/8/2009 10:40'!
initialize
	super initialize.
	fields := OrderedCollection new.! !

!WSFieldHolder methodsFor: 'as yet unclassified' stamp: 'srh 3/9/2009 12:56'!
renderContentOn: html
	html form: [
		fields do: [ :field | html render: field ].
		html submitButton value: 'Save'; callback: [ fields do: [ :field | field save ]]]! !

WATask subclass: #WSTestOrderWizard
	instanceVariableNames: 'order page'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

!WSTestOrderWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:19'!
go
	self answer: order! !

!WSTestOrderWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:58'!
goToFirstPage
	page := 1.! !

!WSTestOrderWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 21:01'!
initialize
	super initialize.
	page := 2.! !

!WSTestOrderWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:19'!
order: anOrder
	order := anOrder! !

!WSTestOrderWizard methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:58'!
page
	^page! !

WSField subclass: #WSTestingField
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Commands'!

!WSTestingField methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 14:07'!
value: newValue
	value := newValue.! !

SCComponentTestCase subclass: #WSFieldTest
	instanceVariableNames: 'field value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Util'!

WSFieldTest subclass: #WSFieldGroupTest
	instanceVariableNames: 'list labels legend'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Util'!

!WSFieldGroupTest methodsFor: 'actions' stamp: 'srh 3/9/2009 12:55'!
addItem: anItem
	(self lastResponse entitiesNamed: 'fieldset') first inputs first value: anItem.
	self submitForm: self lastResponse forms first 
		pressingButton: (self lastResponse buttonWithValue: 'Add' )! !

!WSFieldGroupTest methodsFor: 'accessing' stamp: 'srh 3/11/2009 22:19'!
fieldClass
	^WSFieldGroup! !

!WSFieldGroupTest methodsFor: 'accessing' stamp: 'srh 3/8/2009 09:23'!
fieldset
	^(self lastResponse entitiesNamed: 'fieldset') first! !

!WSFieldGroupTest methodsFor: 'accessing' stamp: 'srh 3/8/2009 11:03'!
itemAt: position
	^(self rowAt: position) entities first! !

!WSFieldGroupTest methodsFor: 'accessing' stamp: 'srh 3/8/2009 10:53'!
itemCount
	^(self lastResponse entitiesNamed: 'tr') size! !

!WSFieldGroupTest methodsFor: 'accessing' stamp: 'srh 3/8/2009 09:56'!
options
	^ (self fieldset entitiesNamed: 'input') first options! !

!WSFieldGroupTest methodsFor: 'actions' stamp: 'srh 3/8/2009 11:02'!
removeItemAt: position 
	self submitForm: self lastResponse forms first
		pressingButton: (((self rowAt: position) entitiesNamed: 'td') at: 2) inputs first.! !

!WSFieldGroupTest methodsFor: 'accessing' stamp: 'srh 3/8/2009 11:00'!
rowAt: position 
	^ (self lastResponse entitiesNamed: 'tr') at: position! !

!WSFieldGroupTest methodsFor: 'running' stamp: 'srh 3/21/2009 21:53'!
setUp
	value := #().
	super setUp.
	list := #(#foo #bar #baz ).
	legend := 'Test Group'.
	labels := #('Foo' 'Bar' 'Baz' ).
	field
		list: list;
		label: legend;
		labels: [ :item | item asCapitalizedPhrase ].
! !

!WSFieldGroupTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testAdd
	self initialRequest.
	self addItem: 'Foo'.
	self assert: 1 = self itemCount! !

!WSFieldGroupTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testAddCorrectItem
	self initialRequest.
	self addItem: 'Bar'.
	self assert: 'bar' = (self itemAt: 1) contentString! !

!WSFieldGroupTest methodsFor: 'tests' stamp: 'srh 3/11/2009 22:13'!
testAddDoesntModifyOriginalBeforeSave
	self initialRequest.
	self addItem: 'Foo'.
	self deny: (value includes: #foo)! !

!WSFieldGroupTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testFactory
	| num |
	num := 0.
	field newItem: 
		[ :item | 
		num := num + 1.
		item displayString , num printString ].
	self initialRequest.
	self addItem: 'Foo'.
	self addItem: 'Bar'.
	self addItem: 'Baz'.
	self assert: 'bar2' = (self itemAt: 2) contentString! !

!WSFieldGroupTest methodsFor: 'tests' stamp: 'srh 3/8/2009 10:12'!
testLabels
	self initialRequest.
	self assert: ((self options collect: [ :o | o contentString ]) hasEqualElements: labels)! !

!WSFieldGroupTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testLegend
	self initialRequest.
	self assert: legend = (self fieldset entitiesNamed: 'legend') first contentString! !

!WSFieldGroupTest methodsFor: 'tests' stamp: 'srh 3/11/2009 22:07'!
testList
	field labels: nil.
	self initialRequest.
	self assert: ((self options collect: [ :o | o contentString ]) hasEqualElements: list)! !

!WSFieldGroupTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testNoItems
	self initialRequest.
	self assert: 0 = self itemCount! !

!WSFieldGroupTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testRemove
	self initialRequest.
	self addItem: 'Foo'.
	self addItem: 'Bar'.
	self removeItemAt: 1.
	self assert: 1 = self itemCount! !

!WSFieldGroupTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testRemoveCorrectItem
	| num |
	num := 0.
	field newItem: 
		[ :item | 
		num := num + 1.
		item displayString , num printString ].
	self initialRequest.
	self addItem: 'Foo'.
	self addItem: 'Bar'.
	self addItem: 'Baz'.
	self removeItemAt: 3.
	self assert: 'bar2' = (self itemAt: 2) contentString! !

!WSFieldGroupTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:47'!
testSave
	self initialRequest.
	self addItem: 'Foo'.
	self save.
	self assert: (value includes: #foo)! !

!WSFieldTest class methodsFor: 'as yet unclassified' stamp: 'srh 3/11/2009 22:08'!
shouldInheritSelectors
	^true! !

!WSFieldTest methodsFor: 'accessing' stamp: 'srh 3/11/2009 22:17'!
fieldClass
	^WSField! !

!WSFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 3/11/2009 22:09'!
initialRequest
	self 
		newApplicationWithRootClass: WSFieldHolder
		createWith: 
			[ WSFieldHolder new
				add: field;
				yourself ].
	self establishSession! !

!WSFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 3/11/2009 22:10'!
save
	self submitForm: self lastResponse forms first 
		pressingButton: (self lastResponse buttonWithValue: 'Save' )! !

!WSFieldTest methodsFor: 'accessing' stamp: 'srh 3/11/2009 22:25'!
setUp
	super setUp.
	field := self fieldClass new 
		label: self fieldClass name;
		on: #value of: self; 
		yourself! !

!WSFieldTest methodsFor: 'accessing' stamp: 'srh 3/11/2009 22:16'!
value
	^ value! !

!WSFieldTest methodsFor: 'accessing' stamp: 'srh 3/11/2009 22:16'!
value: anObject
	value := anObject! !

WSFieldTest subclass: #WSIntegerFieldTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Util'!

!WSIntegerFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 23:18'!
fieldClass
	^WSIntegerField! !

!WSIntegerFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 23:17'!
input
	^self lastResponse forms first textInputs first! !

!WSIntegerFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 23:17'!
testFail
	self initialRequest.
	self input value: 'fail'.
	self save.
	self deny: field valid.! !

!WSIntegerFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 6/28/2009 09:11'!
testFloat
	self initialRequest.
	self input value: '123.45'.
	self save.
	self deny: field valid! !

!WSIntegerFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 23:17'!
testInitialValue
	self initialRequest.
	self assert: '' = self input contentString! !

!WSIntegerFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 23:17'!
testInteger
	self initialRequest.
	self input value: '123'.
	self save.
	self assert: (123 = value).! !

WSFieldTest subclass: #WSNumericFieldTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Util'!

!WSNumericFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 3/11/2009 22:19'!
fieldClass
	^WSNumericField! !

!WSNumericFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 23:13'!
input
	^self lastResponse forms first textInputs first! !

!WSNumericFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 23:15'!
testFail
	self initialRequest.
	self input value: 'fail'.
	self save.
	self deny: field valid.! !

!WSNumericFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 23:14'!
testFloat
	self initialRequest.
	self input value: '123.45'.
	self save.
	self assert: (123.45 closeTo: value).! !

!WSNumericFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testInitialValue
	self initialRequest.
	self assert: '' = self input contentString! !

!WSNumericFieldTest methodsFor: 'as yet unclassified' stamp: 'srh 6/27/2009 23:03'!
testInteger
	self initialRequest.
	self input value: '123'.
	self save.
	self assert: (123 = value).! !

SCComponentTestCase subclass: #WSStoreAdminTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Admin'!

!WSStoreAdminTest methodsFor: 'as yet unclassified' stamp: 'srh 1/24/2009 21:53'!
configureApplicationForComponent: aComponentClass
	super configureApplicationForComponent: aComponentClass.
	app preferenceAt: #sessionClass put: WSTestSession.! !

!WSStoreAdminTest methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 11:47'!
setUp
	self newApplicationWithRootClass: WSStoreAdmin.
	self establishSession.
! !

!WSStoreAdminTest methodsFor: 'as yet unclassified' stamp: 'srh 1/27/2009 20:30'!
testManageOrders
	self followAnchor: (self lastResponse anchorWithLabel: 'Manage Orders').
	self assert: (self lastResponse entitiesNamed: 'label') first contentString 
				= 'Show: '! !

!WSStoreAdminTest methodsFor: 'as yet unclassified' stamp: 'srh 1/3/2009 11:50'!
testManageProducts
	self followAnchor: (self lastResponse anchorWithLabel: 'Manage Products').
	self assert: (self lastResponse entitiesNamed: 'a') first contentString 
				= 'Add Product'! !

SCComponentTestCase subclass: #WSWebTest
	instanceVariableNames: 'store sessionBlock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

WSWebTest subclass: #WSCartViewTest
	instanceVariableNames: 'cart'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

WSCartViewTest subclass: #WSCartViewDialogTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

!WSCartViewDialogTest methodsFor: 'running' stamp: 'srh 3/9/2009 15:50'!
initialRequestWith: aCart
	self newApplicationWithRootClass: WSCartViewDialog
		createWith: [ WSCartViewDialog cart: aCart ].
	self establishSession! !

!WSCartViewDialogTest methodsFor: 'tests' stamp: 'srh 1/4/2009 19:14'!
testBack
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Back').
	self assert: self componentAnswered.! !

!WSCartViewDialogTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testCheckout
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Checkout').
	self assert: 'wizard-tabs' = self lastResponse bodyElement entities first cssClass! !

!WSCartViewDialogTest methodsFor: 'tests' stamp: 'srh 6/28/2009 22:21'!
testEmptyHasNoCheckoutLink
	cart := WSCart new.
	self initialRequest.
	self assert: (self lastResponse anchorsWithLabel: 'Checkout') isEmpty! !

WSCartViewTest subclass: #WSCartViewPageTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

!WSCartViewPageTest methodsFor: 'running' stamp: 'srh 1/4/2009 14:45'!
initialRequestWith: aCart
	self newApplicationWithRootClass: WSCartViewPage 
		initializeWith: [ :c | c model: (WSOrder new items: aCart; yourself) ].
	self establishSession! !

!WSCartViewPageTest methodsFor: 'tests' stamp: 'srh 6/28/2009 22:22'!
testEmptyNotValid
	cart := WSCart new.
	self initialRequest.
	self deny: self component valid! !

!WSCartViewPageTest methodsFor: 'tests' stamp: 'srh 1/4/2009 19:37'!
testEnabled
	self initialRequest.
	self assert: self component enabled! !

!WSCartViewPageTest methodsFor: 'tests' stamp: 'srh 1/4/2009 19:37'!
testValid
	self initialRequest.
	self assert: self component valid! !

!WSCartViewTest class methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 14:47'!
shouldInheritSelectors
	^true! !

!WSCartViewTest methodsFor: 'running' stamp: 'srh 1/4/2009 19:01'!
initialRequest
	self initialRequestWith: cart! !

!WSCartViewTest methodsFor: 'running' stamp: 'srh 3/9/2009 15:50'!
initialRequestWith: aCart
	self newApplicationWithRootClass: WSCartView
		createWith: [ WSCartView cart: aCart ].
	self establishSession! !

!WSCartViewTest methodsFor: 'accessing' stamp: 'srh 1/4/2009 14:06'!
itemCount
	^((self lastResponse entityWithId: 'cart-items') entitiesNamed: 'tr') size.! !

!WSCartViewTest methodsFor: 'accessing' stamp: 'srh 1/4/2009 14:10'!
itemRow: itemNo
	^(((self lastResponse entityWithId: 'cart-items') entitiesNamed: 'tr') at: itemNo) entitiesNamed: 'td'! !

!WSCartViewTest methodsFor: 'accessing' stamp: 'srh 3/21/2009 16:09'!
nameOf: itemNo
	^((self itemRow: itemNo) at: 2) anchors first contentString.! !

!WSCartViewTest methodsFor: 'accessing' stamp: 'srh 1/4/2009 14:16'!
previewFor: itemNo
	^((self itemRow: itemNo) first) entities first! !

!WSCartViewTest methodsFor: 'accessing' stamp: 'srh 1/4/2009 14:15'!
priceOf: itemNo
	^((self itemRow: itemNo) at: 3) contentString.! !

!WSCartViewTest methodsFor: 'accessing' stamp: 'srh 1/4/2009 14:53'!
removeAnchorFor: itemNo
	^((self itemRow: itemNo) at: 4) anchors first.! !

!WSCartViewTest methodsFor: 'running' stamp: 'srh 2/27/2009 20:55'!
setUp
	super setUp.
	cart := WSCart new.
	cart add: store products first.
	cart add: store products second.
! !

!WSCartViewTest methodsFor: 'tests' stamp: 'srh 6/28/2009 22:11'!
testEmpty
	cart := WSCart new.
	self initialRequest.
	self assert: 'Your order contains no items.' = 
	((self lastResponse entitiesWithClass: 'cart-view') first entitiesNamed: 'p') first contentString! !

!WSCartViewTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testItems
	self initialRequest.
	self assert: 2 = self itemCount! !

!WSCartViewTest methodsFor: 'tests' stamp: 'srh 3/28/2009 21:13'!
testNames
	self initialRequest.
	self 
		assert: (store products first) name = (self nameOf: 1).
	self 
		assert: (store products second) name = (self nameOf: 2)
		! !

!WSCartViewTest methodsFor: 'tests' stamp: 'srh 4/14/2009 12:12'!
testPreviews
	self initialRequest.
	self assert: (WSImageLibrary / store products first preview thumbnail) printString = ((self previewFor: 1) attributeAt: 'src').
	self assert: (WSImageLibrary / store products second preview thumbnail) printString = ((self previewFor: 2) attributeAt: 'src')! !

!WSCartViewTest methodsFor: 'tests' stamp: 'srh 8/4/2009 15:37'!
testPrices
	self initialRequest.
	self assert: ('$' , store products first priceInDollars) = (self priceOf: 1).
	self assert: ('$' , store products second priceInDollars) = (self priceOf: 2)! !

!WSCartViewTest methodsFor: 'tests' stamp: 'srh 3/28/2009 21:13'!
testRemoveItem
	self initialRequest.
	self followAnchor: (self removeAnchorFor: 1).
	self assert: 1 = self itemCount! !

!WSCartViewTest methodsFor: 'tests' stamp: 'srh 8/4/2009 15:37'!
testRemoveItemUpdatesTotal
	self initialRequest.
	self followAnchor: (self removeAnchorFor: 1).
	self assert: ('$' , store products second priceInDollars) = self total! !

!WSCartViewTest methodsFor: 'tests' stamp: 'srh 8/4/2009 16:00'!
testTotal
	self initialRequest.
	self assert: ('$' , cart totalInDollars) = self total! !

!WSCartViewTest methodsFor: 'accessing' stamp: 'srh 1/4/2009 14:05'!
total
	^(self lastResponse entityWithId: 'cart-total') contentString! !

WSWebTest subclass: #WSCartWidgetTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

!WSCartWidgetTest methodsFor: 'as yet unclassified' stamp: 'srh 3/10/2009 20:55'!
initialRequestWith: aCart
	self newApplicationWithRootClass: WSComponentHolder
		initializeWith: [ :holder |  holder add: (WSCartWidget new)].
	sessionBlock := [ :s | s cart: aCart].
	self establishSession! !

!WSCartWidgetTest methodsFor: 'tests' stamp: 'srh 8/4/2009 15:37'!
testDetails
	self initialRequestWith: (WSCart new
			add: store products first;
			yourself).
	self assert: ('Items: 1 Total: $' , store products first priceInDollars) = (self lastResponse entitiesNamed: 'p') first contentString! !

!WSCartWidgetTest methodsFor: 'tests' stamp: 'srh 4/25/2009 16:37'!
testEmpty
	self initialRequestWith: WSCart new.
	self assert: (self lastResponse entitiesWithClass: 'cart-widget') isEmpty! !

!WSCartWidgetTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testNotEmpty
	self initialRequestWith: (WSCart new
			add: store products first;
			yourself).
	self assert: 'Your Order' = (self lastResponse entitiesNamed: 'h3') first contentString! !

WSWebTest subclass: #WSCheckoutProcessTest
	instanceVariableNames: 'order'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

!WSCheckoutProcessTest methodsFor: 'initialization' stamp: 'srh 1/4/2009 20:40'!
initialize
	super initialize.
	sessionBlock := [ :s | s store: store]! !

!WSCheckoutProcessTest methodsFor: 'actions' stamp: 'srh 1/4/2009 20:22'!
placeOrder: anOrder
	self newApplicationWithRootClass: WSCheckoutProcess
		initializeWith: [ :c | c wizard:(WSTestOrderWizard new order: anOrder;yourself) ].
	self establishSession! !

!WSCheckoutProcessTest methodsFor: 'running' stamp: 'srh 6/27/2009 11:51'!
setUp
	super setUp.
	order := WSOrder new
		customer: (WSCustomer new
			name: 'Stuart Herring';
			phone: '123459567';
			email: 'testing@example.com');
		address: (WSShippingAddress new
				name: 'Stuart Herring';
				address1: 'Over here';
				locality: 'Testville';
				postcode: '1234';
				state: 'ACT';
				country: (WSCountry byCode: 'AU')).! !

!WSCheckoutProcessTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testPlaceOrder
	order items: (WSCart new
			add: store products first;
			yourself).
	self placeOrder: order.
	self assert: '/us/cgi-bin/webscr' = self browser history last key url! !

WSWebTest subclass: #WSImageManagerTest
	instanceVariableNames: 'p'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Admin'!

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:07'!
initialRequest
	self newApplicationWithRootClass: WSImageManager
		createWith: [ WSImageManager for: p ].
	self establishSession! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 14:04'!
setUp
	super setUp.
	p := store products first.! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testAdd
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Add Image').
	self assert: SCFileHtmlInput = (self lastResponse entitiesNamed: 'input') first class! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 14:19'!
testDelete
	| i|
	i := p images first.
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Delete') first.
	self deny: (p images includes: i)! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 14:08'!
testDone
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Done').
	self assert: self componentAnswered.! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testEdit
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Edit') first.
	self assert: SCFileHtmlInput = (self lastResponse entitiesNamed: 'input') first class! !

!WSImageManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testSetAsPreview
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Set as Preview') second.
	self assert: p images second = p preview! !

WSWebTest subclass: #WSOrderManagerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Admin'!

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:58'!
formatDate: aDate
	^aDate asDate printFormat: #(3 2 1 $- 1 1 2).! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:10'!
initialRequest
	self newApplicationWithRootClass: WSOrderManager
		createWith: [ WSOrderManager store: store ].
	self establishSession! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/29/2009 13:49'!
rows
	| table |
	table := (self lastResponse entitiesNamed: 'table') first.
	^(table entitiesNamed: 'tr') allButFirst collect: [ :tr | tr entitiesNamed: 'td' ]! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 17:42'!
testCancel
	self initialRequest.
	self followAnchor: (self  lastResponse anchorWithLabel: 'Cancel').
	self answerRequestWith: 'because'.
	self assert: ((self rows first at: 6) contentString beginsWith: 'Cancelled')! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/29/2009 13:49'!
testDone
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Done').
	self assert: self componentAnswered.! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testFilter
	| form |
	self initialRequest.
	form := self lastResponse forms first.
	(form entitiesNamed: #input) first selectOptionWithText: 'Cancelled'.
	self submitForm: form.
	self assert: 1 = self rows size! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 22:10'!
testFilterSelectsCorrectRecords
	| form | 
	self initialRequest.
	form := 	self lastResponse forms first.
	(form entitiesNamed: #input) first selectOptionWithText: 'Cancelled'.
	self submitForm: form.
	self assert: ((self rows first at: 6) contentString beginsWith: 'Cancelled')! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testListSize
	self initialRequest.
	self assert: store orders size = self rows size! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 21:12'!
testShip
	self initialRequest.
	self followAnchor: (self  lastResponse anchorWithLabel: 'Ship').
	self confirmYes.
	self assert: (((self rows at: 3) at: 6) contentString beginsWith: 'Shipped')! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testShowCancelledDate
	| o |
	o := store orders second.
	self initialRequest.
	self assert: ('Cancelled (' , (self formatDate: o status date) , ')') = (self rows second at: 6) contentString! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testShowItems
	self initialRequest.
	self assert: store orders first items count printString = (self rows first at: 3) contentString! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testShowName
	self initialRequest.
	self assert: store orders first customer name = self rows first second contentString! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 5/4/2009 18:08'!
testShowReference
	self initialRequest.
	self assert: store orders first reference = self rows first first entities first contentString! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testShowShippedDate
	| o |
	o := store orders third.
	self initialRequest.
	self assert: ('Shipped (' , (self formatDate: o status date) , ')') = (self rows last at: 6) contentString! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 16:43'!
testShowStatus
	self initialRequest.
	self assert:  (((self rows first) at: 6) contentString beginsWith: (store orders first status name asCapitalizedPhrase))! !

!WSOrderManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 8/4/2009 16:00'!
testShowTotal
	self initialRequest.
	self assert: ('$' , store orders first items totalInDollars) = (self rows first at: 4) contentString! !

WSWebTest subclass: #WSPaypalCheckoutTest
	instanceVariableNames: 'order paypalEmail paypalHost'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

!WSPaypalCheckoutTest methodsFor: 'subclass hooks' stamp: 'srh 2/27/2009 20:32'!
configureApplicationForComponent: aComponentClass 
	super configureApplicationForComponent: aComponentClass.
	app configuration addAncestor: WSConfiguration new.
	app 
		preferenceAt: #paypalHost
		put: paypalHost.
	app 
		preferenceAt: #accountEmail
		put: paypalEmail! !

!WSPaypalCheckoutTest methodsFor: 'as yet unclassified' stamp: 'srh 2/27/2009 20:38'!
fieldNamed: aName 
	^ self browser history last key getFields at: aName! !

!WSPaypalCheckoutTest methodsFor: 'running' stamp: 'srh 2/22/2009 16:52'!
initialRequest
	self newApplicationWithRootClass: WSPayPalCheckout   createWith: [ WSPayPalCheckout  order: order ].
	self establishSession! !

!WSPaypalCheckoutTest methodsFor: 'running' stamp: 'srh 6/27/2009 11:50'!
setUp
	super setUp.
	paypalEmail := 'test@example.com'.
	paypalHost := 'localhost'.
	order := WSOrder new
		customer: (WSCustomer new
			name: 'Stuart Herring';
			phone: '123459567';
			email: 'testing@example.com');
		address: (WSShippingAddress new
				name: 'Stuart Herring';
				address1: 'Over here';
				address2: 'Over there';
				locality: 'Testville';
				postcode: '1234';
				state: 'ACT';
				country: (WSCountry byCode: 'AU')).
	order items: (WSCart new add: store products first; add: store products second;yourself).
! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testAddress1
	self initialRequest.
	self assert: order address address1 = (self fieldNamed: 'address1') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testAddress2
	self initialRequest.
	self assert: order address address2 = (self fieldNamed: 'address2') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testCity
	self initialRequest.
	self assert: order address locality = (self fieldNamed: 'city') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testCmd
	self initialRequest.
	self assert: '_cart' = (self fieldNamed: 'cmd') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 6/27/2009 15:50'!
testCountry
	self initialRequest.
	self assert: order address country code = (self fieldNamed: 'country') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testCurrency
	self initialRequest.
	self assert: 'AUD' = (self fieldNamed: 'currency_code') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 4/11/2009 12:55'!
testFirstName
	self initialRequest.
	self assert: (order customer name findTokens: ' ') first = (self fieldNamed: 'first_name') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 8/4/2009 15:37'!
testItemAmount
	self initialRequest.
	self assert: order items items first priceInDollars = (self fieldNamed: 'amount_1') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:53'!
testItemCount
	self initialRequest.
	self assert: order items count = (self browser history last key getFields keys select: [ :f | f beginsWith: 'item_name_' ]) size! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testItemName
	self initialRequest.
	self assert: order items items first name = (self fieldNamed: 'item_name_1') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 4/11/2009 12:56'!
testLastName
	self initialRequest.
	self assert: (order customer name findTokens: ' ') last = (self fieldNamed: 'last_name') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testPaypalEmail
	self initialRequest.
	self assert: paypalEmail = (self fieldNamed: 'business') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testRm
	self initialRequest.
	self assert: '2' = (self fieldNamed: 'rm') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testState
	self initialRequest.
	self assert: order address state = (self fieldNamed: 'state') value! !

!WSPaypalCheckoutTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testUpload
	self initialRequest.
	self assert: '1' = (self fieldNamed: 'upload') value! !

WSWebTest subclass: #WSProductDetailsTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

!WSProductDetailsTest methodsFor: 'running' stamp: 'cmd 3/21/2009 17:18'!
initialRequest
	self newApplicationWithRootClass: WSProductDetails
		createWith: [ WSProductDetails for: store products first  ].
	self establishSession! !

WSWebTest subclass: #WSProductEditorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Admin'!

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/8/2009 23:16'!
addType: typeName
	self selectType value: typeName.
	self 
		submitForm: self lastResponse forms first 
		pressingButton: (self lastResponse buttonWithValue: 'Add' )! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/8/2009 22:54'!
initialRequest
	self newApplicationWithRootClass: WSProductEditor
		createWith: [ WSProductEditor product: store products first ].
	self establishSession! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/9/2009 00:08'!
save
	self 
		submitForm: self lastResponse forms first
		pressingButton: (self lastResponse buttonWithValue: 'Save')! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/8/2009 23:09'!
selectType
	^ self lastResponse inputs detect: [ :i | i isSelectInput ]! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testAddOption
	self initialRequest.
	self addType: 'Text'.
	self assert: 'Text' = ((self lastResponse entitiesNamed: 'fieldset') first entitiesNamed: 'label') first contentString! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/8/2009 23:00'!
testCancelAnswers
	self initialRequest.
	self 
		submitForm: self lastResponse  forms first 
		pressingButton: (self lastResponse buttonWithValue: 'Cancel').
	
	self assert: self componentAnswered! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testExistingOption
	store products first options: (OrderedCollection with: (WSTextOption new
				name: 'Text Option';
				yourself)).
	self initialRequest.
	self assert: 'Text Option' = ((self lastResponse entitiesNamed: 'fieldset') first inputs at: 3) value! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/9/2009 00:17'!
testNewOptionIsBlank
	self initialRequest.
	self addType: 'Text'.
	self assert: ((self lastResponse entitiesNamed: 'fieldset') first inputs at: 3) value isNil! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:47'!
testOptions
	self initialRequest.
	self assert: ((self selectType options collect: [ :o | o contentString ]) includes: 'Text')! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/9/2009 00:08'!
testSaveAnswers
	self initialRequest.
	self save.
	self assert: self componentAnswered! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/9/2009 12:04'!
testSaveIncompleteDoesntAnswer
	self initialRequest.
	self addType: 'Text'.
	"Simulate a real form submit - if we don't do this, the value will be 'nil', which is considered OK 
	(so as to allow the first rendering to not be full of errors)"
	((self lastResponse entitiesNamed: 'fieldset') first inputs at: 3) value: ''.
	
	self save.
	self deny: self componentAnswered.
! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testSaveWithOption
	self initialRequest.
	self addType: 'Text'.
	((self lastResponse entitiesNamed: 'fieldset') first inputs at: 3) value: 'New Value'.
	self save.
	self assert: 'New Value' = store products first options first name! !

!WSProductEditorTest methodsFor: 'as yet unclassified' stamp: 'srh 3/9/2009 00:23'!
testSaveWithOptionAnswers
	self initialRequest.
	self addType: 'Text'.
	((self lastResponse entitiesNamed: 'fieldset') first inputs at: 3) value: 'New Value'.
	self save.
	self assert: self componentAnswered.! !

WSWebTest subclass: #WSProductImageViewTest
	instanceVariableNames: 'product'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

!WSProductImageViewTest methodsFor: 'running' stamp: 'cmd 3/21/2009 17:23'!
initialRequest
	self newApplicationWithRootClass: WSProductImageView 
		createWith: [ WSProductImageView for: store products first  ].
	self establishSession! !

!WSProductImageViewTest methodsFor: 'running' stamp: 'cmd 3/21/2009 17:42'!
setUp
	super setUp.
	product := store products first! !

!WSProductImageViewTest methodsFor: 'tests' stamp: 'cmd 3/21/2009 17:46'!
testCurrentThumbnail
	self initialRequest.
	self assert: (((self lastResponse entitiesNamed: 'li') first entities first attributeAt: 'src') endsWith: product preview thumbnail)! !

!WSProductImageViewTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testCurrentThumbnailNotALink
	self initialRequest.
	self assert: 'img' = (self lastResponse entitiesNamed: 'li') first entities first tag! !

!WSProductImageViewTest methodsFor: 'tests' stamp: 'cmd 3/21/2009 17:30'!
testInitialCurrent
	self initialRequest.
	self assert: (((self lastResponse entitiesNamed: 'img') first attributeAt: 'src') endsWith: product preview medium).! !

!WSProductImageViewTest methodsFor: 'tests' stamp: 'cmd 3/21/2009 17:32'!
testInitialCurrentLink
	self initialRequest.
	self assert: ((self lastResponse anchors first attributeAt: 'href') endsWith: product preview fullsize)! !

!WSProductImageViewTest methodsFor: 'tests' stamp: 'cmd 3/21/2009 17:39'!
testNavigation
	self initialRequest.
	self followAnchor: ((self lastResponse entitiesNamed: 'li') second anchors first).
	self assert: (((self lastResponse entitiesNamed: 'img') first attributeAt: 'src') endsWith: product images second medium).! !

!WSProductImageViewTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testNavigationAffectsImageStrip
	self initialRequest.
	self followAnchor: (self lastResponse entitiesNamed: 'li') second anchors first.
	self assert: 'a' = (self lastResponse entitiesNamed: 'li') first entities first tag! !

!WSProductImageViewTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testNavigationAffectsImageStrip2
	self initialRequest.
	self followAnchor: (self lastResponse entitiesNamed: 'li') second anchors first.
	self assert: 'img' = (self lastResponse entitiesNamed: 'li') second entities first tag! !

!WSProductImageViewTest methodsFor: 'tests' stamp: 'cmd 3/21/2009 17:46'!
testOtherThumbnail
	self initialRequest.
	self assert: ((((self lastResponse entitiesNamed: 'li') second entitiesNamed: 'img') first attributeAt: 'src') endsWith: product images second thumbnail)! !

!WSProductImageViewTest methodsFor: 'tests' stamp: 'srh 3/28/2009 22:45'!
testThumbnails
	self initialRequest.
	self assert: product images size = (self lastResponse entitiesNamed: 'li') size! !

WSWebTest subclass: #WSProductManagerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-Admin'!

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 2/5/2009 21:09'!
initialRequest
	self newApplicationWithRootClass: WSProductManager
		createWith: [ WSProductManager store: store ].
	self establishSession! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:31'!
rows
	| table |
	table := (self lastResponse entitiesNamed: 'table') first.
	^(table entitiesNamed: 'tr') allButFirst collect: [ :tr | tr entitiesNamed: 'td' ]! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testAdd
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Add Product').
	self assert: 'Name:' = (self lastResponse entitiesNamed: 'label') first contentString! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testDelete
	| name |
	name := store products second name.
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Delete') second.
	self assert: ('Really delete ' , name , '?') = (self lastResponse entitiesNamed: 'h3') first contentString! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testDeleteCancel
	| size |
	size := store products size.
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Delete') second.
	self confirmNo.
	self assert: size = self rows size! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testDeleteConfirm
	| size |
	size := store products size.
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Delete') second.
	self confirmYes.
	self assert: size - 1 = self rows size! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:49'!
testDeleteRemovesCorrectItem
	| name |
	name :=  store products second name.
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Delete') second.
	self confirmYes.
	self deny: (self rows anySatisfy: [:r | name = r second contentString ])! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:08'!
testDone
	self initialRequest.
	self followAnchor: (self lastResponse anchorWithLabel: 'Done').
	self assert: self componentAnswered.! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testEdit
	self initialRequest.
	self followAnchor: (self lastResponse anchorsWithLabel: 'Edit') first.
	self assert: 'Name:' = (self lastResponse entitiesNamed: 'label') first contentString! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testList
	self initialRequest.
	self assert: store products second name = self rows second second contentString! !

!WSProductManagerTest methodsFor: 'as yet unclassified' stamp: 'srh 3/28/2009 22:45'!
testListSize
	self initialRequest.
	self assert: store products size = self rows size! !

WSWebTest subclass: #WSProductPreviewTest
	instanceVariableNames: 'product'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WebStoreTests-UI'!

!WSProductPreviewTest methodsFor: 'running' stamp: 'srh 4/10/2009 14:41'!
initialRequest
	self 
		newApplicationWithRootClass: WSComponentHolder
		initializeWith: [ :holder | holder add: (WSProductPreview  product: product) ].
	self establishSession! !

!WSProductPreviewTest methodsFor: 'running' stamp: 'srh 3/10/2009 21:37'!
setUp
	super setUp.
	product := store products first.! !

!WSProductPreviewTest methodsFor: 'tests' stamp: 'srh 8/4/2009 15:45'!
testName
	self initialRequest.
	self assert: product name = (self lastResponse entitiesNamed: 'h3') first contentString! !

!WSProductPreviewTest methodsFor: 'tests' stamp: 'srh 8/4/2009 16:10'!
testPreviewImage
	self initialRequest.
	self assert: (WSImageLibrary / product preview preview) printString = ((self lastResponse bodyElement entitiesNamed: 'img') first attributeAt: 'src')! !

!WSProductPreviewTest methodsFor: 'tests' stamp: 'srh 8/4/2009 16:13'!
testPrice
	self initialRequest.
	self assert: ('$' , product priceInDollars, '  ') = (self lastResponse entitiesNamed: 'p') first contentString! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 2/28/2009 21:13'!
answerRequestWith: text
	| form |
	form := self lastResponse forms first.
	form textInputs first value: text.
	self submitForm: form pressingButton: (form buttons detect: [:b | b value = 'Ok']).
! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 2/22/2009 13:37'!
configureApplicationForComponent: aComponentClass
	super configureApplicationForComponent: aComponentClass.
	app preferenceAt: #sessionClass put: WSTestSession.! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:47'!
confirmNo
	| form |
	form := self lastResponse forms first.
	self submitForm: form pressingButton: (form buttons detect: [:b | b value = 'No']).
! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 1/26/2009 16:47'!
confirmYes
	| form |
	form := self lastResponse forms first.
	self submitForm: form pressingButton: (form buttons detect: [:b | b value = 'Yes']).
! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 1/4/2009 20:39'!
sessionCreated: aSession
	sessionBlock ifNotNil: [ sessionBlock value: aSession]! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 22:37'!
setUp
	super setUp.
	store := WSTestingStore store.
! !

!WSWebTest methodsFor: 'as yet unclassified' stamp: 'srh 1/25/2009 16:06'!
store
	^store! !
